pub fn parse_log_stream(
lines: impl IntoIterator<Item = String>,
) -> Vec<ParsedLogLine>Expand description
Parse a stream of log lines: JSON lines become typed columns, plain lines keep only the raw text.
pub fn parse_log_stream(
lines: impl IntoIterator<Item = String>,
) -> Vec<ParsedLogLine>Parse a stream of log lines: JSON lines become typed columns, plain lines keep only the raw text.