pub enum Projection {
Tui,
Gui,
Browser,
}Expand description
A projection (which frontend or agent surface).
Only the rendering projections are here. Headless and MCP are consumers of the
semantic layer (they read the data plane and action graph, they never render a
surface), so they are a different axis — not members of this enum. Modelling them as
projections that are always None conflates two distinct concepts and implies that
e.g. MCP “cannot do graph things”, when in fact MCP’s blast_radius tool is graph
data (ADR-0013).
Variants